@@ -46,3 +46,7 @@ def create_article(theme, line_num=200):
 # @except_dec()
 def pwd4wifi(len_pwd=8, pwd_list=[]):
     wftools.pwd4wifi(len_pwd, pwd_list)
+
+# 测试网速
+def net_speed_test():
+    wftools.net_speed_test()
\ No newline at end of file
